Lires document

## 条目编辑窗口

通过点击主页右上角工具栏中的`添加条目 (New)`按钮，或点击扩展数据卡中的`Edit`按钮， 可以进入条目编辑页面。条目编辑页面中可编辑包括文献信息、标签和URL在内的条目信息。

下方展示了条目编辑界面，在界面左侧可以输入文献信息（目前支持bibtex、endnote和nbib格式）和URL，右侧可以添加标签。

当数据卡片展开，并且鼠标悬停在数据卡片上时，可以使用空格键进入编辑界面

## 文献信息录入

当上述窗口打开时，除了手动粘贴录入文献信息，还可使用如下方式提升信息输入效率：

1. 向信息输入框内拖入文本文档（如bibtex文件），此时将会将文本文档内容读取并输入文献信息栏。
2. 当有文献索引号（如ArXiv ID、DOI）时，可以点击`Bibtex`标签旁的`from-source`按钮，此时将弹出如下界面，可使尝试使用文献索引号从网络获取文献信息。
3. 当需要完全手动输入时，可以点击`Bibtex`标签旁的`template`，此时可以选择插入bibtex模版，以辅助录入

## 标签录入

通过右侧的标签栏即可选择现有标签或添加新标签。 标签栏选择框内显示标签为文献库中所有标签的集合，通过点击即可选择现有标签。 标签支持多级嵌套，当需要添加新的多级标签时，需要使用`->`符号将层级标签相连，如下图所示：
在输入新标签后，`ADD`按钮会高亮显示，点击即可添加新标签。

## URL录入

通过在URL栏内输入即可添加URL。 URL的作用是作为条目的补充信息，或作为网页文献的替代品。 当没有上传文件时，将以URL作为文件的替代品。